@@ -1,8 +1,8 @@
-"""
+print("""
 FUNCTIONS:
     matrix_1 - основная работа программы
 Shpeka,Chernov,Kaxorov,Martishenya
-"""
+""")
 
 
 import random
@@ -13,15 +13,20 @@ from scipy.linalg import solve
 import time
 
 def matrix_1(): 
-    """оберточная функция matrix_1()
-    вызывает интерфейс все функций"""
+    """FUNCTIONS:
+    matrix_1 - основная работа программы
+    выполнять решать СЛАУ методом
+    Gaussa and Jacoby
+    authors:
+        Shpeka,Chernov,Kaxorov,Martishenya
+    """
     print(matrix_1.__doc__)
     matrix=[] 
     def minor(array):
-    """функция minor нужна чтобы найти определитель если матрица 2x2"""
+        """функция minor нужна чтобы найти определитель если матрица 2x2"""
         return array[0][0] * array[1][1] - array[1][0] * array[0][1] 
     def division(array):
-    """division нужен чтобы решать матрицу 3x3 и тд"""
+        """division нужен чтобы решать матрицу 3x3 и тд"""
         if len(array[0]) > 2:
             result = 0
             for i in range(len(array[0])):
@@ -34,7 +39,7 @@ def matrix_1():
         else:
             return minor(array)
     def makeTriangleNaive(matrix):
-    """ функция меняет матрицу через побочные эффекты
+        """ функция меняет матрицу через побочные эффекты
             nrow равен номеру строки
             row содержит саму строку матрицы"""
         
@@ -117,7 +122,7 @@ def matrix_1():
 
         return A[:,-1]
     def Jacoby(A,b,x,n):
-    """Решает матрицу по Jacoby"""
+        """Решает матрицу по Jacoby"""
 
         D=np.diag(A)
         R=A-np.diagflat(D)
@@ -125,14 +130,14 @@ def matrix_1():
             x=(b-np.dot(R,x))/D
         return(x)
     def frac(x):
-    """функция frac преобразовывет ввод дробных чисел
-    например: 3/5 он преобразует в 0.6"""
+        """функция frac преобразовывет ввод дробных чисел
+        например: 3/5 он преобразует в 0.6"""
         np.set_printoptions(formatter = {
            'all': lambda x: str(fractions.Fraction(x))
         })
         return x
     def visual():
-    """Рисует красивую систему равнений"""
+        """Рисует красивую систему равнений"""
         print("System:" )
         for i in range(A.shape[0]):
             row = ["{}*x{}" .format(A[i, j], j + 1) for j in range(A.shape[1])]
@@ -355,5 +360,5 @@ def matrix_1():
                 print(t2-t1)
                 
 
-print(matrixg.__doc__)
+print(matrix_1.__doc__)
 
